Learn R Programming

DPWeibull (version 1.8)

survmedian: The median of the surivival functions generated by LIO prior

Description

This data set gives the median of 20000 random survival functions generated by our LIO prior on a 0 to 10 scale. This data set is primarily used for determining scale parameter when heavy end-of-study censoring is present.

Arguments